@@ -3,7 +3,7 @@
   packageStartupMessage("                        Welcome to the package 'quarks'!")
   packageStartupMessage("********************************************************************************")
   packageStartupMessage("")
-  packageStartupMessage("Please report any possible errors and bugs to sebastian.let@t-online.de.")
+  packageStartupMessage("Please report any possible errors and bugs to sebastian.let@yahoo.com.")
   packageStartupMessage("")
   packageStartupMessage("                              Thank you.")
   packageStartupMessage("")
