@@ -75,7 +75,9 @@ print.quarks <- function(x, ...) {
     cat("|            Traffic Light Test            |", fill = TRUE)
     cat("--------------------------------------------", fill = TRUE)
     cat(" Method:", method, fill = TRUE)
+    if (method %in% c("Volatility Weighting", "Filtered")) {
     cat(" Model: ", x[["model"]], fill = TRUE)
+    }
     cat("--------------------------------------------", fill = TRUE)
     cat("|       Traffic light zone boundaries      |", fill = TRUE)
     cat("--------------------------------------------", fill = TRUE)
@@ -114,6 +116,9 @@ print.quarks <- function(x, ...) {
     if (x[["method"]] == "fhs") {
       method = "Filtered"
     }
+    if (x[["method"]] == "NA") {
+      method = "NA"
+    }
     cat(" ", fill = TRUE)
     cat("--------------------------------------------", fill = TRUE)
     cat("|               Test results               |", fill = TRUE)
@@ -127,7 +132,7 @@ print.quarks <- function(x, ...) {
     cat(" ", fill = TRUE)
     cat("p_[uc] = ", round(x[["p.uc"]], 4), sep = "", fill = TRUE)
     cat(" ", fill = TRUE)
-    if (x[["p.uc"]] <= (1 - x[["conflvl"]])) {
+    if (x[["p.uc"]] < (1 - x[["conflvl"]])) {
       cat("Decision: Reject H0", fill = TRUE)
     } else {
       cat("Decision: Fail to reject H0", fill = TRUE)
@@ -139,7 +144,7 @@ print.quarks <- function(x, ...) {
     cat(" ", fill = TRUE)
     cat("p_[ind] = ", round(x[["p.ind"]], 4), sep = "", fill = TRUE)
     cat(" ", fill = TRUE)
-    if (x[["p.ind"]] <= (1 - x[["conflvl"]])) {
+    if (x[["p.ind"]] < (1 - x[["conflvl"]])) {
       cat("Decision: Reject H0", fill = TRUE)
     } else {
       cat("Decision: Fail to reject H0", fill = TRUE)
@@ -151,7 +156,7 @@ print.quarks <- function(x, ...) {
     cat(" ", fill = TRUE)
     cat("p_[cc] = ", round(x[["p.cc"]], 4), sep = "", fill = TRUE)
     cat(" ", fill = TRUE)
-    if (x[["p.cc"]] <= (1 - x[["conflvl"]])) {
+    if (x[["p.cc"]] < (1 - x[["conflvl"]])) {
       cat("Decision: Reject H0", fill = TRUE)
     } else {
       cat("Decision: Fail to reject H0", fill = TRUE)
